:mod:`kwant.qsymm` -- Integration with `Qsymm <https://gitlab.kwant-project.org/qt/qsymm>`_
===========================================================================================

.. automodule:: kwant.qsymm
   :members:
   :special-members:
   :exclude-members: __weakref__
